text_responsive library
Classes
- InlineTextWidget
- A widget designed to provide responsive text functionality for inline text.
- ParagraphTextWidget
- A widget that provides responsive text functionality for paragraph text.
- TextResponsiveWidget
- A responsive text widget that automatically adjusts font size to fit available space.